// Copyright (C) 2020 Guido Berhoerster <guido+sievemgr@berhoerster.name>
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package main

import (
	"fmt"
	"io"
	"io/ioutil"
	"os"
)

func init() {
	cmdCheckSpace.Flag.StringVar(&acctName, "a", "", "Select the account")
}

var cmdCheckSpace = &command{
	UsageLine: "checkspace [options] name [file]",
	Run:       runCheckSpace,
}

func runCheckSpace(cmd *command, args []string) error {
	var err error
	acct, err := getAccount(&conf, acctName)
	if err != nil {
		return err
	}

	var scriptName string
	var scriptSize int64
	switch len(args) {
	case 2: // name and filename
		scriptName = args[0]
		info, err := os.Stat(args[1])
		if err != nil {
			return fmt.Errorf("failed to stat script file: %s\n", err)
		}
		scriptSize = info.Size()
	case 1: // only name
		scriptName = args[0]
		scriptSize, err = io.Copy(ioutil.Discard, os.Stdin)
		if err != nil {
			return fmt.Errorf("failed to read script: %s\n",
				err)
		}
	default:
		return usageError("invalid number of arguments")
	}

	if err := lookupHostPort(acct); err != nil {
		return err
	}

	if err := readPassword(acct); err != nil {
		return err
	}

	c, err := dialPlainAuth(acct)
	if err != nil {
		return err
	}
	defer c.Logout()

	if ok, err := c.HaveSpace(scriptName, scriptSize); err != nil {
		return err
	} else if !ok {
		return errTooBig
	}

	return nil
}
